Struct safe_arch::m256d[][src]

#[repr(transparent)]
pub struct m256d(pub __m256d);
The data for a 256-bit AVX register of four f64 values.

  • This is very similar to having [f64; 4]. The main difference is that it’s aligned to 32 instead of just 4, and of course you can perform various intrinsic operations on it.

Implementations

Transmutes the m256d to an array.

Same as m.into(), just lets you be more explicit about what’s happening.

Transmutes an array into m256d.

Same as m256d::from(arr), it just lets you be more explicit about what’s happening.

Converts into the bit patterns of these doubles ([u64;4]).

Like f64::to_bits, but both lanes at once.

Converts from the bit patterns of these doubles ([u64;4]).

Like f64::from_bits, but both lanes at once.